@@ -1,6 +1,6 @@
 /*
  * This file is part of the Gopherus project.
- * Copyright (C) 2019 Mateusz Viste
+ * Copyright (C) 2019-2022 Mateusz Viste
  */
 
 #include <stdio.h>
@@ -10,14 +10,22 @@
 #include "fs.h"
 
 /* returns path and filename of the bookmark file */
-char *bookmarks_getfname(const char *argv0) {
-  static char r[512];
-  snprintf(r, sizeof(r), "%s/Gopherus", getenv("APPDATA"));
-  CreateDirectory(r, NULL);
-  snprintf(r, sizeof(r), "%s/Gopherus/gopherus.bkm", getenv("APPDATA"));
-  return(r);
+char *bookmarks_getfname(char *s, size_t ssz) {
+  snprintf(s, ssz, "%s/Gopherus", getenv("APPDATA"));
+  CreateDirectory(s, NULL);
+  snprintf(s, ssz, "%s/Gopherus/gopherus.bkm", getenv("APPDATA"));
+  return(s);
 }
 
+
+char *config_getfname(char *s, size_t ssz) {
+  snprintf(s, ssz, "%s/Gopherus", getenv("APPDATA"));
+  CreateDirectory(s, NULL);
+  snprintf(s, ssz, "%s/Gopherus/gopherus.cfg", getenv("APPDATA"));
+  return(s);
+}
+
+
 void filetrunc(const char *fname, long sz) {
   HANDLE fh;
   fh = CreateFileA(fname, GENERIC_WRITE, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
